@@ -9,7 +9,7 @@ from argparse import ArgumentParser
 
 from ..args import (add_generic_args, add_diff_args, add_merge_args,
     add_web_args, add_filename_args, args_for_server, args_for_browse,
-    process_diff_flags)
+    process_diff_flags, Path)
 from .nbdimeserver import main_server as run_server
 from .webutil import browse
 
@@ -31,6 +31,7 @@ def build_arg_parser():
     add_filename_args(parser, ["base", "local", "remote"])
     parser.add_argument(
         '--out',
+        type=Path,
         default=None,
         help="if supplied, the merged notebook is written "
              "to this file. Otherwise it cannot be saved.")
